@@ -1,3 +1,4 @@
+import random
 from openpower.consts import FastRegsEnum
 from openpower.decoder.power_enums import SPRfull as SPR, spr_dict
 
@@ -51,3 +52,7 @@ def mask_extend(x, nbits, repeat):
     return res
     
 
+# makes a logarithmically-skewed random number
+def log_rand(n, min_val=1):
+    logrange = random.randint(1, n)
+    return random.randint(min_val, (1 << logrange)-1)
